blohg is written and maintained by Rafael G. Martins and
various contributors:

Development Lead
~~~~~~~~~~~~~~~~

- Rafael G. Martins <rafael@rafaelmartins.eng.br>


Patches and Suggestions
~~~~~~~~~~~~~~~~~~~~~~~

- Anton Novosyolov
- Benoit Allard
- Bruno Yporti
- Christian Joergensen
- Ry4an Brase
